@@ -13,7 +13,6 @@ import subprocess
 import sys
 from tempfile import TemporaryDirectory
 import time
-import typing as t
 from warnings import warn
 
 from typing import Dict as DictType, Any as AnyType
@@ -31,7 +30,6 @@ from traitlets import (
     Instance,
     Any,
 )
-import inspect
 from traitlets.config import SingletonConfigurable
 
 from .completer import ZMQCompleter
@@ -78,29 +76,7 @@ from pygments.lexers import get_lexer_by_name
 from pygments.util import ClassNotFound
 from pygments.token import Token
 
-from jupyter_core.utils import run_sync as _run_sync
-
-
-T = t.TypeVar("T")
-
-
-def run_sync(coro: t.Callable[..., t.Union[T, t.Awaitable[T]]]) -> t.Callable[..., T]:
-    """Wraps coroutine in a function that blocks until it has executed.
-
-    Parameters
-    ----------
-    coro : coroutine-function
-        The coroutine-function to be executed.
-
-    Returns
-    -------
-    result :
-        Whatever the coroutine-function returns.
-    """
-    if not inspect.iscoroutinefunction(coro):
-        return t.cast(t.Callable[..., T], coro)
-    return _run_sync(coro)
-
+from jupyter_console.utils import run_sync
 
 
 def ask_yes_no(prompt, default=None, interrupt=None):
